@@ -26,30 +26,31 @@
 #include "ewstypes.h"
 
 const EwsServerVersion EwsServerVersion::ewsVersion2007(8, 0, QStringLiteral("Exchange2007"),
-        QStringLiteral("Exchange 2007"));
+                                                        QStringLiteral("Exchange 2007"));
 const EwsServerVersion EwsServerVersion::ewsVersion2007Sp1(8, 1, QStringLiteral("Exchange2007_SP1"),
-        QStringLiteral("Exchange 2007 SP1"));
+                                                           QStringLiteral("Exchange 2007 SP1"));
 const EwsServerVersion EwsServerVersion::ewsVersion2007Sp2(8, 2, QStringLiteral("Exchange2007_SP2"),
-        QStringLiteral("Exchange 2007 SP2"));
+                                                           QStringLiteral("Exchange 2007 SP2"));
 const EwsServerVersion EwsServerVersion::ewsVersion2007Sp3(8, 3, QStringLiteral("Exchange2007_SP3"),
-        QStringLiteral("Exchange 2007 SP3"));
+                                                           QStringLiteral("Exchange 2007 SP3"));
 const EwsServerVersion EwsServerVersion::ewsVersion2010(14, 0, QStringLiteral("Exchange2010"),
-        QStringLiteral("Exchange 2010"));
+                                                        QStringLiteral("Exchange 2010"));
 const EwsServerVersion EwsServerVersion::ewsVersion2010Sp1(14, 1, QStringLiteral("Exchange2010_SP1"),
-        QStringLiteral("Exchange 2010 SP1"));
+                                                           QStringLiteral("Exchange 2010 SP1"));
 const EwsServerVersion EwsServerVersion::ewsVersion2010Sp2(14, 2, QStringLiteral("Exchange2010_SP2"),
-        QStringLiteral("Exchange 2010 SP2"));
+                                                           QStringLiteral("Exchange 2010 SP2"));
 const EwsServerVersion EwsServerVersion::ewsVersion2010Sp3(14, 3, QStringLiteral("Exchange2010_SP3"),
-        QStringLiteral("Exchange 2010 SP3"));
+                                                           QStringLiteral("Exchange 2010 SP3"));
 const EwsServerVersion EwsServerVersion::ewsVersion2013(15, 0, QStringLiteral("Exchange2013"),
-        QStringLiteral("Exchange 2013"));
+                                                        QStringLiteral("Exchange 2013"));
 const EwsServerVersion EwsServerVersion::ewsVersion2016(15, 1, QStringLiteral("Exchange2016"),
-        QStringLiteral("Exchange 2016"));
+                                                        QStringLiteral("Exchange 2016"));
 
 static const EwsServerVersion ewsNullVersion;
 
 EwsServerVersion::EwsServerVersion(QXmlStreamReader &reader)
-    : mMajor(0), mMinor(0)
+    : mMajor(0)
+    , mMinor(0)
 {
     // <h:ServerVersionInfo MajorVersion=\"14\" MinorVersion=\"3\" MajorBuildNumber=\"248\"
     // MinorBuildNumber=\"2\" Version=\"Exchange2010_SP2\" />
