@@ -17,7 +17,7 @@
     02110-1301, USA.
 */
 
-#include "config.h"
+#include <config.h>
 
 #include <string.h>
 #include <stdlib.h>
