@@ -12,7 +12,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "kolabobject.h"
@@ -183,7 +183,7 @@ KOLAB_EXPORT QString generateMemberUrl(const RelationMember &member)
     path << "/";
     if (!member.user.isEmpty()) {
         path << "user";
-        path << QUrl::toPercentEncoding(member.user.toLatin1());
+        path << QUrl::toPercentEncoding(member.user);
     } else {
         path << "shared";
     }
